﻿using AuthenticationServices;
using KerberosSSOA.Pages;
using KerberosSSOA.Services;
using System;
using System.ComponentModel;
using UIKit;
using Xamarin.Forms;

namespace KerberosSSOA.iOS
{
    public class MainPageViewModel : UIViewController, IMainPageViewModel, IASAuthorizationControllerPresentationContextProviding
    {
        public Command SignInCommand { get; }

        public Command SignOutCommand { get; }

        public string SignedInLabel
        {
            get => _signedInLabel;
            set
            {
                _signedInLabel = value;
                PropertyChanged.Invoke(this, new PropertyChangedEventArgs("SignedInLabel"));
            }
        }

        public MainPageViewModel(IAuthenticationService authenticationService)
        {
            m_authenticationService = authenticationService;

            m_authenticationService.OnSignedInChanged += OnSignedInChanged;

            SignInCommand = new Command(() => m_authenticationService.SignIn(this));
            SignOutCommand = new Command(() => m_authenticationService.SignOut(this));

            m_authenticationService.SignIn(this);
        }

        public UIWindow GetPresentationAnchor(ASAuthorizationController controller)
        {
            return View.Window;
        }

        private void OnSignedInChanged(object sender, EventArgs e)
        {
            SignedInLabel = m_authenticationService.IsSignedIn ? "You are signed in!" : "You are not signed in.";
        }

        private readonly IAuthenticationService m_authenticationService;

        public event PropertyChangedEventHandler PropertyChanged;
        private string _signedInLabel;
    }
}