//
//  AuthenticationViewController.swift
//  SSOExtensionProA
//
//  Created by trd-studs on 29/04/2021.
//

import UIKit
import AuthenticationServices

class AuthenticationViewController : UIViewController, ASAuthorizationControllerPresentationContextProviding {
    
    func presentationAnchor(for controller: ASAuthorizationController) -> ASPresentationAnchor {
        return self.view.window!
    }
    
    var authController: ASAuthorizationController?
    var authProvider = ASAuthorizationSingleSignOnProvider(identityProvider: URL(string: "")!)
    
    override func viewDidLoad() {
        super.viewDidLoad()
        view.backgroundColor = .systemBackground
        view.addSubview(signInButton)
        signInButton.addTarget(self, action: #selector(didTapSignIn), for: .touchUpInside)
        
        let canAuthorize = AuthManager.shared.authProvider.canPerformAuthorization
        let label = UILabel(frame: CGRect(x: 0, y: 0, width: 300, height: 21))
        label.center = CGPoint(x: 160, y: 285)
        label.textAlignment = .center
        if canAuthorize == true {
            label.text = "Can authorize application!"
        } else {
            label.text = "Cannot authorize application."
        }
        self.view.addSubview(label)
    }
    
    override func viewDidLayoutSubviews() {
        super.viewDidLayoutSubviews()
        signInButton.frame = CGRect(x:20, y:50, width: 100, height: 50)
        signInButton.center = view.center
    }
    
    @objc func didTapSignIn() {
        signIn()
    }
    
    private func signIn() {
        AuthManager.shared.signIn(sender: self)
    }
    
    func authorizationController(controller: ASAuthorizationController,
                                          didCompleteWithError error: Error) {
        let alert: UIAlertController = UIAlertController(title: "Error", message: error.localizedDescription, preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK", style: .cancel, handler: nil))
        self.present(alert, animated: true)
    }
    
    func authorizationController(controller: ASAuthorizationController,
                                 didCompleteWithAuthorization authorization: ASAuthorization) {

        let alert: UIAlertController = UIAlertController(title: "Success", message: "Yay", preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK", style: .cancel, handler: nil))
        self.present(alert, animated: true)
    }
    
    private let signInButton: UIButton = {
        let button = UIButton()
        button.backgroundColor = .red
        button.setTitle("Sign In", for: .normal)
        button.setTitleColor(.white, for: .normal)
        return button
    }()
}
