//
//  AuthManager.swift
//  SSOExtensionProA
//
//  Created by trd-studs on 29/04/2021.
//

import AuthenticationServices

class AuthManager : NSObject, ASAuthorizationControllerDelegate {
    static var shared = AuthManager()
    
    var isSignedIn: Bool = false
    
    var authController: ASAuthorizationController?
    var currentView: UIViewController?
    public var authProvider = ASAuthorizationSingleSignOnProvider(identityProvider: URL(string: "")!)
    
    public func signIn(sender: UIViewController) {
        let request = self.authProvider.createRequest()
        
        request.requestedOperation = ASAuthorization.OpenIDOperation.operationLogin
        request.authorizationOptions = [
            URLQueryItem(name: "scope", value: "openid%20offline_access%20profile"),
            URLQueryItem(name: "response_type", value: "code"),
            URLQueryItem(name: "redirect_uri", value: "dips-sso://login-callback"),
            URLQueryItem(name: "client_id", value: "")
        ]
        
        currentView = sender
        
        self.authController = ASAuthorizationController(authorizationRequests: [request])
        self.authController?.delegate = self
        self.authController?.presentationContextProvider = sender as? ASAuthorizationControllerPresentationContextProviding
        self.authController?.performRequests()
    }
    
    func authorizationController(controller: ASAuthorizationController,
                                          didCompleteWithError error: Error) {
        let alert: UIAlertController = UIAlertController(title: "Error", message: error.localizedDescription, preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK", style: .cancel, handler: nil))
        
        currentView?.present(alert, animated: true)
    }
    
    func authorizationController(controller: ASAuthorizationController,
                                 didCompleteWithAuthorization authorization: ASAuthorization) {
        isSignedIn = true
        let alert: UIAlertController = UIAlertController(title: "Success", message: "Yay", preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK", style: .cancel, handler: nil))
        currentView?.present(alert, animated: true)
    }
}
